@@ -11,14 +11,14 @@ const int32_t CFFI_COMPUTED_I32 = -2147483647;
 
 typedef enum cffi_enumdocumented
     {
-    CFFI_A = 0,
-    CFFI_B = 1,
-    CFFI_C = 2,
+    CFFI_ENUMDOCUMENTED_A = 0,
+    CFFI_ENUMDOCUMENTED_B = 1,
+    CFFI_ENUMDOCUMENTED_C = 2,
     } cffi_enumdocumented;
 
 typedef enum cffi_enumrenamed
     {
-    CFFI_X = 0,
+    CFFI_ENUMRENAMED_X = 0,
     } cffi_enumrenamed;
 
 typedef struct cffi_generic2u8 cffi_generic2u8;
@@ -26,15 +26,14 @@ typedef struct cffi_generic3 cffi_generic3;
 typedef struct cffi_generic4 cffi_generic4;
 typedef struct cffi_opaque cffi_opaque;
 typedef struct cffi_simpleservice cffi_simpleservice;
-typedef struct cffi_somecontext cffi_somecontext;
 typedef struct cffi_empty cffi_empty;
 
 typedef enum cffi_ffierror
     {
-    CFFI_OK = 0,
-    CFFI_NULL = 100,
-    CFFI_PANIC = 200,
-    CFFI_FAIL = 300,
+    CFFI_FFIERROR_OK = 0,
+    CFFI_FFIERROR_NULL = 100,
+    CFFI_FFIERROR_PANIC = 200,
+    CFFI_FFIERROR_FAIL = 300,
     } cffi_ffierror;
 
 typedef struct cffi_extratypef32
@@ -149,35 +148,35 @@ typedef cffi_tupled (*cffi_fptr_fn_Tupled_rval_Tupled)(cffi_tupled x0);
 
 typedef bool (*cffi_fptr_fn_pmut_i64_rval_bool)(int64_t* x0);
 
-typedef struct cffi_ffisliceffibool
+typedef struct cffi_slicebool
     {
     uint8_t* data;
     uint64_t len;
-    } cffi_ffisliceffibool;
+    } cffi_slicebool;
 
-typedef struct cffi_ffisliceu32
+typedef struct cffi_sliceu32
     {
     uint32_t* data;
     uint64_t len;
-    } cffi_ffisliceu32;
+    } cffi_sliceu32;
 
-typedef struct cffi_ffisliceu8
+typedef struct cffi_sliceu8
     {
     uint8_t* data;
     uint64_t len;
-    } cffi_ffisliceu8;
+    } cffi_sliceu8;
 
-typedef struct cffi_ffislicemutu8
+typedef struct cffi_slicemutu8
     {
     uint8_t* data;
     uint64_t len;
-    } cffi_ffislicemutu8;
+    } cffi_slicemutu8;
 
-typedef struct cffi_ffioptioninner
+typedef struct cffi_optioninner
     {
     cffi_inner t;
     uint8_t is_some;
-    } cffi_ffioptioninner;
+    } cffi_optioninner;
 
 typedef struct cffi_myapiv1
     {
@@ -185,17 +184,17 @@ typedef struct cffi_myapiv1
     cffi_fptr_fn_Tupled_rval_Tupled tupled;
     } cffi_myapiv1;
 
-typedef struct cffi_ffislicevec3f32
+typedef struct cffi_slicevec3f32
     {
     cffi_vec3f32* data;
     uint64_t len;
-    } cffi_ffislicevec3f32;
+    } cffi_slicevec3f32;
 
-typedef uint8_t (*cffi_fptr_fn_FFISliceu8_rval_u8)(cffi_ffisliceu8 x0);
+typedef uint8_t (*cffi_fptr_fn_Sliceu8_rval_u8)(cffi_sliceu8 x0);
 
-typedef void (*cffi_fptr_fn_FFISliceMutu8)(cffi_ffislicemutu8 x0);
+typedef void (*cffi_fptr_fn_SliceMutu8)(cffi_slicemutu8 x0);
 
-typedef cffi_vec3f32 (*cffi_fptr_fn_FFISliceVec3f32_rval_Vec3f32)(cffi_ffislicevec3f32 x0);
+typedef cffi_vec3f32 (*cffi_fptr_fn_SliceVec3f32_rval_Vec3f32)(cffi_slicevec3f32 x0);
 
 
 void primitive_void();
@@ -241,35 +240,28 @@ bool weird_1(cffi_weird1u32 _x, cffi_weird2u8 _y);
 void visibility(cffi_visibility1 _x, cffi_visibility2 _y);
 uint32_t pattern_ascii_pointer_1(uint8_t* x);
 uint32_t pattern_ascii_pointer_len(uint8_t* x, cffi_useasciistringpattern y);
-uint32_t pattern_ffi_slice_1(cffi_ffisliceu32 ffi_slice);
-cffi_vec3f32 pattern_ffi_slice_2(cffi_ffislicevec3f32 ffi_slice, int32_t i);
-void pattern_ffi_slice_3(cffi_ffislicemutu8 slice, cffi_fptr_fn_FFISliceMutu8 callback);
-uint8_t pattern_ffi_slice_delegate(cffi_fptr_fn_FFISliceu8_rval_u8 callback);
-cffi_vec3f32 pattern_ffi_slice_delegate_huge(cffi_fptr_fn_FFISliceVec3f32_rval_Vec3f32 callback);
-cffi_ffioptioninner pattern_ffi_option_1(cffi_ffioptioninner ffi_slice);
-cffi_inner pattern_ffi_option_2(cffi_ffioptioninner ffi_slice);
+uint32_t pattern_ffi_slice_1(cffi_sliceu32 ffi_slice);
+cffi_vec3f32 pattern_ffi_slice_2(cffi_slicevec3f32 ffi_slice, int32_t i);
+void pattern_ffi_slice_3(cffi_slicemutu8 slice, cffi_fptr_fn_SliceMutu8 callback);
+uint8_t pattern_ffi_slice_delegate(cffi_fptr_fn_Sliceu8_rval_u8 callback);
+cffi_vec3f32 pattern_ffi_slice_delegate_huge(cffi_fptr_fn_SliceVec3f32_rval_Vec3f32 callback);
+cffi_optioninner pattern_ffi_option_1(cffi_optioninner ffi_slice);
+cffi_inner pattern_ffi_option_2(cffi_optioninner ffi_slice);
 uint8_t pattern_ffi_bool(uint8_t ffi_bool);
 void pattern_my_api_init_v1(cffi_myapiv1* api);
 uint64_t pattern_api_guard();
-void simple_service_ext_util(cffi_simpleservice* _ptr);
 uint32_t pattern_callback_1(cffi_fptr_fn_u32_rval_u32 callback, uint32_t x);
-cffi_ffierror pattern_service_create(cffi_somecontext** context_ptr, uint32_t value);
-cffi_ffierror pattern_service_destroy(cffi_somecontext** context_ptr);
-uint32_t pattern_service_method(cffi_somecontext* context);
-cffi_ffierror pattern_service_method_success_enum_ok(cffi_somecontext* _context);
-cffi_ffierror pattern_service_method_success_enum_fail(cffi_somecontext* _context);
-cffi_ffierror simple_service_create(cffi_simpleservice** context_ptr, uint32_t x);
-cffi_ffierror simple_service_destroy(cffi_simpleservice** context_ptr);
-cffi_ffierror simple_service_result(cffi_simpleservice* context_ptr, uint32_t x);
-uint32_t simple_service_value(cffi_simpleservice* context_ptr, uint32_t x);
-uint8_t simple_service_mut_self(cffi_simpleservice* context_ptr, cffi_ffisliceu8 slice);
-void simple_service_mut_self_void(cffi_simpleservice* context_ptr, cffi_ffisliceffibool slice);
-uint8_t simple_service_mut_self_ref(cffi_simpleservice* context_ptr, uint8_t* x, uint8_t* _y);
-uint8_t simple_service_mut_self_ref_slice(cffi_simpleservice* context_ptr, uint8_t* x, uint8_t* _y, cffi_ffisliceu8 _slice);
-uint8_t simple_service_mut_self_ref_slice_limited(cffi_simpleservice* context_ptr, uint8_t* x, uint8_t* _y, cffi_ffisliceu8 _slice, cffi_ffisliceu8 _slice2);
-cffi_ffierror simple_service_mut_self_ffi_error(cffi_simpleservice* context_ptr, cffi_ffislicemutu8 slice);
-void simple_service_void(cffi_simpleservice* context_ptr);
-uint32_t simple_service_extra_method(cffi_simpleservice* _context);
+cffi_ffierror simple_service_new_with(cffi_simpleservice** context, uint32_t some_value);
+cffi_ffierror simple_service_destroy(cffi_simpleservice** context);
+cffi_ffierror simple_service_method_result(cffi_simpleservice* context, uint32_t _anon1);
+uint32_t simple_service_method_value(cffi_simpleservice* context, uint32_t x);
+void simple_service_method_void(cffi_simpleservice* context);
+uint8_t simple_service_method_mut_self(cffi_simpleservice* context, cffi_sliceu8 slice);
+void simple_service_method_mut_self_void(cffi_simpleservice* context, cffi_slicebool _slice);
+uint8_t simple_service_method_mut_self_ref(cffi_simpleservice* context, uint8_t* x, uint8_t* _y);
+uint8_t simple_service_method_mut_self_ref_slice(cffi_simpleservice* context, uint8_t* x, uint8_t* _y, cffi_sliceu8 _slice);
+uint8_t simple_service_method_mut_self_ref_slice_limited(cffi_simpleservice* context, uint8_t* x, uint8_t* _y, cffi_sliceu8 _slice, cffi_sliceu8 _slice2);
+cffi_ffierror simple_service_method_mut_self_ffi_error(cffi_simpleservice* context, cffi_slicemutu8 _slice);
 """
 
 
@@ -295,7 +287,7 @@ COMPUTED_I32 = -2147483647
 
 
 class EnumDocumented:
-    """Documented enum."""
+    """ Documented enum."""
     A = 0
     B = 1
     C = 2
@@ -514,7 +506,7 @@ class SomeForeignType(object):
         self._ctx[0].x = value
 
 class StructDocumented(object):
-    """Documented struct."""
+    """ Documented struct."""
     def __init__(self):
         global _api, ffi
         self._ctx = ffi.new("cffi_structdocumented[]", 1)
@@ -528,7 +520,7 @@ class StructDocumented(object):
 
     @property
     def x(self):
-        """Documented field."""
+        """ Documented field."""
         return self._ctx[0].x
 
     @x.setter
@@ -894,9 +886,9 @@ class callbacks:
     fn_Tupled_rval_Tupled = "cffi_tupled(cffi_tupled)"
     fn_pmut_i64_rval_bool = "bool(int64_t*)"
     fn_u8_rval_u8 = "uint8_t(uint8_t)"
-    fn_FFISliceu8_rval_u8 = "uint8_t(cffi_ffisliceu8)"
-    fn_FFISliceVec3f32_rval_Vec3f32 = "cffi_vec3f32(cffi_ffislicevec3f32)"
-    fn_FFISliceMutu8 = "void(cffi_ffislicemutu8)"
+    fn_Sliceu8_rval_u8 = "uint8_t(cffi_sliceu8)"
+    fn_SliceVec3f32_rval_Vec3f32 = "cffi_vec3f32(cffi_slicevec3f32)"
+    fn_SliceMutu8 = "void(cffi_slicemutu8)"
     fn_u32_rval_u32 = "uint32_t(uint32_t)"
 
 
@@ -1025,9 +1017,9 @@ class raw:
         return _api.ptr(x)
 
     def ptr_mut(x):
-        """# Safety
+        """ # Safety
 
-Parameter x must point to valid data."""
+ Parameter x must point to valid data."""
         global _api
         if hasattr(x, "_ctx"):
             x = x._ctx[0]
@@ -1156,7 +1148,7 @@ Parameter x must point to valid data."""
         return _api.array_1(x)
 
     def documented(_x):
-        """This function has documentation."""
+        """ This function has documentation."""
         global _api
         if hasattr(_x, "_ctx"):
             _x = _x._ctx[0]
@@ -1317,13 +1309,6 @@ Parameter x must point to valid data."""
         global _api
         return _api.pattern_api_guard()
 
-    def simple_service_ext_util(_ptr):
-        """"""
-        global _api
-        if hasattr(_ptr, "_ctx"):
-            _ptr = _ptr._ctx[0]
-        return _api.simple_service_ext_util(_ptr)
-
     def pattern_callback_1(callback, x):
         """"""
         global _api
@@ -1333,126 +1318,102 @@ Parameter x must point to valid data."""
             x = x._ctx[0]
         return _api.pattern_callback_1(callback, x)
 
-    def pattern_service_create(context_ptr, value):
-        """"""
+    def simple_service_new_with(context, some_value):
+        """ The constructor must return a `Result<Self, Error>`."""
         global _api
-        if hasattr(context_ptr, "_ctx"):
-            context_ptr = context_ptr._ctx[0]
-        if hasattr(value, "_ctx"):
-            value = value._ctx[0]
-        return _api.pattern_service_create(context_ptr, value)
+        if hasattr(context, "_ctx"):
+            context = context._ctx[0]
+        if hasattr(some_value, "_ctx"):
+            some_value = some_value._ctx[0]
+        return _api.simple_service_new_with(context, some_value)
 
-    def pattern_service_destroy(context_ptr):
-        """# Safety
+    def simple_service_destroy(context):
+        """ Destroys the given instance.
 
-This function may only be called with a context returned by a succeeding `pattern_service_create`."""
+ # Safety
+
+ The passed parameter MUST have been created with the corresponding init function;
+ passing any other value results in undefined behavior."""
         global _api
-        if hasattr(context_ptr, "_ctx"):
-            context_ptr = context_ptr._ctx[0]
-        return _api.pattern_service_destroy(context_ptr)
+        if hasattr(context, "_ctx"):
+            context = context._ctx[0]
+        return _api.simple_service_destroy(context)
 
-    def pattern_service_method(context):
+    def simple_service_method_result(context, _anon1):
+        """ Methods returning a Result<(), _> are the default and do not
+ need annotations."""
+        global _api
+        if hasattr(context, "_ctx"):
+            context = context._ctx[0]
+        if hasattr(_anon1, "_ctx"):
+            _anon1 = _anon1._ctx[0]
+        return _api.simple_service_method_result(context, _anon1)
+
+    def simple_service_method_value(context, x):
         """"""
         global _api
         if hasattr(context, "_ctx"):
             context = context._ctx[0]
-        return _api.pattern_service_method(context)
-
-    def pattern_service_method_success_enum_ok(_context):
-        """"""
-        global _api
-        if hasattr(_context, "_ctx"):
-            _context = _context._ctx[0]
-        return _api.pattern_service_method_success_enum_ok(_context)
-
-    def pattern_service_method_success_enum_fail(_context):
-        """"""
-        global _api
-        if hasattr(_context, "_ctx"):
-            _context = _context._ctx[0]
-        return _api.pattern_service_method_success_enum_fail(_context)
-
-    def simple_service_create(context_ptr, x):
-        """"""
-        global _api
-        if hasattr(context_ptr, "_ctx"):
-            context_ptr = context_ptr._ctx[0]
         if hasattr(x, "_ctx"):
             x = x._ctx[0]
-        return _api.simple_service_create(context_ptr, x)
+        return _api.simple_service_method_value(context, x)
 
-    def simple_service_destroy(context_ptr):
+    def simple_service_method_void(context):
+        """ This method should be documented.
+
+ Multiple lines."""
+        global _api
+        if hasattr(context, "_ctx"):
+            context = context._ctx[0]
+        return _api.simple_service_method_void(context)
+
+    def simple_service_method_mut_self(context, slice):
         """"""
         global _api
-        if hasattr(context_ptr, "_ctx"):
-            context_ptr = context_ptr._ctx[0]
-        return _api.simple_service_destroy(context_ptr)
-
-    def simple_service_result(context_ptr, x):
-        """"""
-        global _api
-        if hasattr(context_ptr, "_ctx"):
-            context_ptr = context_ptr._ctx[0]
-        if hasattr(x, "_ctx"):
-            x = x._ctx[0]
-        return _api.simple_service_result(context_ptr, x)
-
-    def simple_service_value(context_ptr, x):
-        """"""
-        global _api
-        if hasattr(context_ptr, "_ctx"):
-            context_ptr = context_ptr._ctx[0]
-        if hasattr(x, "_ctx"):
-            x = x._ctx[0]
-        return _api.simple_service_value(context_ptr, x)
-
-    def simple_service_mut_self(context_ptr, slice):
-        """"""
-        global _api
-        if hasattr(context_ptr, "_ctx"):
-            context_ptr = context_ptr._ctx[0]
+        if hasattr(context, "_ctx"):
+            context = context._ctx[0]
         if hasattr(slice, "_ctx"):
             slice = slice._ctx[0]
-        return _api.simple_service_mut_self(context_ptr, slice)
+        return _api.simple_service_method_mut_self(context, slice)
 
-    def simple_service_mut_self_void(context_ptr, slice):
+    def simple_service_method_mut_self_void(context, _slice):
+        """ Single line."""
+        global _api
+        if hasattr(context, "_ctx"):
+            context = context._ctx[0]
+        if hasattr(_slice, "_ctx"):
+            _slice = _slice._ctx[0]
+        return _api.simple_service_method_mut_self_void(context, _slice)
+
+    def simple_service_method_mut_self_ref(context, x, _y):
         """"""
         global _api
-        if hasattr(context_ptr, "_ctx"):
-            context_ptr = context_ptr._ctx[0]
-        if hasattr(slice, "_ctx"):
-            slice = slice._ctx[0]
-        return _api.simple_service_mut_self_void(context_ptr, slice)
-
-    def simple_service_mut_self_ref(context_ptr, x, _y):
-        """"""
-        global _api
-        if hasattr(context_ptr, "_ctx"):
-            context_ptr = context_ptr._ctx[0]
+        if hasattr(context, "_ctx"):
+            context = context._ctx[0]
         if hasattr(x, "_ctx"):
             x = x._ctx[0]
         if hasattr(_y, "_ctx"):
             _y = _y._ctx[0]
-        return _api.simple_service_mut_self_ref(context_ptr, x, _y)
+        return _api.simple_service_method_mut_self_ref(context, x, _y)
 
-    def simple_service_mut_self_ref_slice(context_ptr, x, _y, _slice):
+    def simple_service_method_mut_self_ref_slice(context, x, _y, _slice):
         """"""
         global _api
-        if hasattr(context_ptr, "_ctx"):
-            context_ptr = context_ptr._ctx[0]
+        if hasattr(context, "_ctx"):
+            context = context._ctx[0]
         if hasattr(x, "_ctx"):
             x = x._ctx[0]
         if hasattr(_y, "_ctx"):
             _y = _y._ctx[0]
         if hasattr(_slice, "_ctx"):
             _slice = _slice._ctx[0]
-        return _api.simple_service_mut_self_ref_slice(context_ptr, x, _y, _slice)
+        return _api.simple_service_method_mut_self_ref_slice(context, x, _y, _slice)
 
-    def simple_service_mut_self_ref_slice_limited(context_ptr, x, _y, _slice, _slice2):
+    def simple_service_method_mut_self_ref_slice_limited(context, x, _y, _slice, _slice2):
         """"""
         global _api
-        if hasattr(context_ptr, "_ctx"):
-            context_ptr = context_ptr._ctx[0]
+        if hasattr(context, "_ctx"):
+            context = context._ctx[0]
         if hasattr(x, "_ctx"):
             x = x._ctx[0]
         if hasattr(_y, "_ctx"):
@@ -1461,89 +1422,29 @@ This function may only be called with a context returned by a succeeding `patter
             _slice = _slice._ctx[0]
         if hasattr(_slice2, "_ctx"):
             _slice2 = _slice2._ctx[0]
-        return _api.simple_service_mut_self_ref_slice_limited(context_ptr, x, _y, _slice, _slice2)
+        return _api.simple_service_method_mut_self_ref_slice_limited(context, x, _y, _slice, _slice2)
 
-    def simple_service_mut_self_ffi_error(context_ptr, slice):
+    def simple_service_method_mut_self_ffi_error(context, _slice):
         """"""
         global _api
-        if hasattr(context_ptr, "_ctx"):
-            context_ptr = context_ptr._ctx[0]
-        if hasattr(slice, "_ctx"):
-            slice = slice._ctx[0]
-        return _api.simple_service_mut_self_ffi_error(context_ptr, slice)
-
-    def simple_service_void(context_ptr):
-        """"""
-        global _api
-        if hasattr(context_ptr, "_ctx"):
-            context_ptr = context_ptr._ctx[0]
-        return _api.simple_service_void(context_ptr)
-
-    def simple_service_extra_method(_context):
-        """An extra exposed method."""
-        global _api
-        if hasattr(_context, "_ctx"):
-            _context = _context._ctx[0]
-        return _api.simple_service_extra_method(_context)
+        if hasattr(context, "_ctx"):
+            context = context._ctx[0]
+        if hasattr(_slice, "_ctx"):
+            _slice = _slice._ctx[0]
+        return _api.simple_service_method_mut_self_ffi_error(context, _slice)
 
 
 
 
 
-class SomeContext(object):
-    def __init__(self, value):
-        """"""
-        global _api, ffi
-        if hasattr(value, "_ctx"):
-            value = value._ctx
-        self.ctx = ffi.new("cffi_somecontext**")
-        rval = raw.pattern_service_create(self.ctx, value)
-        if rval == FFIError.Ok:
-            return None
-        else:
-            raise Exception(f"return value ${rval}")
-
-    def __del__(self):
-        global _api, ffi
-        rval = raw.pattern_service_destroy(self.ctx, )
-        if rval == FFIError.Ok:
-            return None
-        else:
-            raise Exception(f"return value ${rval}")
-
-    def method(self, ):
-        """"""
-        global raw
-        return _api.pattern_service_method(self.ctx[0], )
-
-    def method_success_enum_ok(self, ):
-        """"""
-        global raw
-        rval = raw.pattern_service_method_success_enum_ok(self.ctx[0], )
-        if rval == FFIError.Ok:
-            return None
-        else:
-            raise Exception(f"return value ${rval}")
-
-    def method_success_enum_fail(self, ):
-        """"""
-        global raw
-        rval = raw.pattern_service_method_success_enum_fail(self.ctx[0], )
-        if rval == FFIError.Ok:
-            return None
-        else:
-            raise Exception(f"return value ${rval}")
-
-
-
 class SimpleService(object):
-    def __init__(self, x):
-        """"""
+    def __init__(self, some_value):
+        """ The constructor must return a `Result<Self, Error>`."""
         global _api, ffi
-        if hasattr(x, "_ctx"):
-            x = x._ctx
+        if hasattr(some_value, "_ctx"):
+            some_value = some_value._ctx
         self.ctx = ffi.new("cffi_simpleservice**")
-        rval = raw.simple_service_create(self.ctx, x)
+        rval = raw.simple_service_new_with(self.ctx, some_value)
         if rval == FFIError.Ok:
             return None
         else:
@@ -1557,64 +1458,62 @@ class SimpleService(object):
         else:
             raise Exception(f"return value ${rval}")
 
-    def result(self, x):
-        """"""
+    def method_result(self, _anon1):
+        """ Methods returning a Result<(), _> are the default and do not
+ need annotations."""
         global raw
-        rval = raw.simple_service_result(self.ctx[0], x)
+        rval = raw.simple_service_method_result(self.ctx[0], _anon1)
         if rval == FFIError.Ok:
             return None
         else:
             raise Exception(f"return value ${rval}")
 
-    def value(self, x):
+    def method_value(self, x):
         """"""
         global raw
-        return _api.simple_service_value(self.ctx[0], x)
+        return _api.simple_service_method_value(self.ctx[0], x)
 
-    def mut_self(self, slice):
-        """"""
-        global raw
-        return _api.simple_service_mut_self(self.ctx[0], slice)
+    def method_void(self, ):
+        """ This method should be documented.
 
-    def mut_self_void(self, slice):
-        """"""
+ Multiple lines."""
         global raw
-        return _api.simple_service_mut_self_void(self.ctx[0], slice)
+        return _api.simple_service_method_void(self.ctx[0], )
 
-    def mut_self_ref(self, x, _y):
+    def method_mut_self(self, slice):
         """"""
         global raw
-        return _api.simple_service_mut_self_ref(self.ctx[0], x, _y)
+        return _api.simple_service_method_mut_self(self.ctx[0], slice)
 
-    def mut_self_ref_slice(self, x, _y, _slice):
-        """"""
+    def method_mut_self_void(self, _slice):
+        """ Single line."""
         global raw
-        return _api.simple_service_mut_self_ref_slice(self.ctx[0], x, _y, _slice)
+        return _api.simple_service_method_mut_self_void(self.ctx[0], _slice)
 
-    def mut_self_ref_slice_limited(self, x, _y, _slice, _slice2):
+    def method_mut_self_ref(self, x, _y):
         """"""
         global raw
-        return _api.simple_service_mut_self_ref_slice_limited(self.ctx[0], x, _y, _slice, _slice2)
+        return _api.simple_service_method_mut_self_ref(self.ctx[0], x, _y)
 
-    def mut_self_ffi_error(self, slice):
+    def method_mut_self_ref_slice(self, x, _y, _slice):
         """"""
         global raw
-        rval = raw.simple_service_mut_self_ffi_error(self.ctx[0], slice)
+        return _api.simple_service_method_mut_self_ref_slice(self.ctx[0], x, _y, _slice)
+
+    def method_mut_self_ref_slice_limited(self, x, _y, _slice, _slice2):
+        """"""
+        global raw
+        return _api.simple_service_method_mut_self_ref_slice_limited(self.ctx[0], x, _y, _slice, _slice2)
+
+    def method_mut_self_ffi_error(self, _slice):
+        """"""
+        global raw
+        rval = raw.simple_service_method_mut_self_ffi_error(self.ctx[0], _slice)
         if rval == FFIError.Ok:
             return None
         else:
             raise Exception(f"return value ${rval}")
 
-    def void(self, ):
-        """"""
-        global raw
-        return _api.simple_service_void(self.ctx[0], )
-
-    def extra_method(self, ):
-        """An extra exposed method."""
-        global raw
-        return _api.simple_service_extra_method(self.ctx[0], )
-
 
 
 
